@@ -49,7 +49,7 @@ class Debugged(object):
 					"line_number": traceback.tb_lineno(tback),
 					"character_number": -1,
 					"filename": exc_info[Debugged.EXC_INFO_FILENAME],
-					"user_custom_data": 235236,
+					"user_custom_data": finished_local_data,
 					"sdk_data": {
 					}
 				})
